/**
 * Copyright (c) 2011-2012 EBMWebsourcing, 2012-2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.component.framework.logger;

import static org.junit.Assert.assertEquals;

import java.util.Map;

import org.junit.Test;
import org.ow2.petals.commons.log.FlowLogData;
import org.ow2.petals.commons.log.TraceCode;

/**
 * @author Mathieu Carrolle - EBM WebSourcing
 */
public class ProvideFlowStepBeginLogDataTest extends AbstractFlowLogDataTest {

    private static final String TEST_FLOW_STEP_INTERFACE_NAME_STR = "{http://org.ow2.petals.test1}testFlowStepInterfaceName";

    private static final String TEST_FLOW_STEP_SERVICE_NAME_STR = "{http://org.ow2.petals.test2}testFlowStepServiceName";

    private static final String TEST_FLOW_STEP_OPERATION_NAME_STR = "{http://org.ow2.petals.test3}testFlowStepOperationName";

    private static final String TEST_FLOW_STEP_ENDPOINT_NAME = "testFlowStepEndPointName";

    private static final String TEST_FLOW_PREVIOUS_STEP_ID = "testFlowPreviousStepId";

    @Test
    public void testConstructor() {
        TraceCode traceCode = TraceCode.PROVIDE_FLOW_STEP_BEGIN;
        ProvideFlowStepBeginLogData logData = new ProvideFlowStepBeginLogData(
                TEST_FLOW_INSTANCE_ID, TEST_FLOW_STEP_ID, TEST_FLOW_STEP_INTERFACE_NAME_STR,
                TEST_FLOW_STEP_SERVICE_NAME_STR, TEST_FLOW_STEP_OPERATION_NAME_STR,
                TEST_FLOW_STEP_ENDPOINT_NAME, TEST_FLOW_PREVIOUS_STEP_ID, null);

        assertEquals(createExpectedLogData(traceCode), logData);
    }

    @Override
    protected Map<String, Object> createExpectedLogData(TraceCode traceCode) {
        final Map<String, Object> expectedLogData = super.createExpectedLogData(traceCode);
        expectedLogData.put(FlowLogData.FLOW_STEP_INTERFACE_NAME_PROPERTY_NAME,
                TEST_FLOW_STEP_INTERFACE_NAME_STR);
        expectedLogData.put(FlowLogData.FLOW_STEP_SERVICE_NAME_PROPERTY_NAME,
                TEST_FLOW_STEP_SERVICE_NAME_STR);
        expectedLogData.put(FlowLogData.FLOW_STEP_OPERATION_NAME_PROPERTY_NAME,
                TEST_FLOW_STEP_OPERATION_NAME_STR);
        expectedLogData.put(FlowLogData.FLOW_STEP_ENDPOINT_NAME_PROPERTY_NAME,
                TEST_FLOW_STEP_ENDPOINT_NAME);
        expectedLogData.put(FlowLogData.FLOW_PREVIOUS_STEP_ID_PROPERTY_NAME,
                TEST_FLOW_PREVIOUS_STEP_ID);
        expectedLogData.put(FlowLogData.FLOW_EXCHANGE_PROPERTY_NAME, null);
        return expectedLogData;
    }

}
